==> ZenTaoPMS.max2.4.php7.1.zip: zentaopms/module/milestone/lang/zh-tw.php <==
<?php
$lang->milestone->common      = '項目里程碑報告';
$lang->milestone->index       = '報告首頁';
$lang->milestone->title       = '里程碑報告';
$lang->milestone->name        = '里程碑名稱';
$lang->milestone->stage       = '里程碑階段';
$lang->milestone->save        = '保存';

$lang->milestone->indexAction = '里程碑報告';

$lang->milestone->startedWeeks  = '開始周數';
$lang->milestone->finishedWeeks = '結束周數';
$lang->milestone->offset        = '里程碑工期偏差';

$lang->milestone->processCommon = '項目當前進展狀況';
$lang->milestone->process       = '項目進度';
$lang->milestone->executionCost   = '項目成本';
$lang->milestone->toNow         = '到目前為止';
$lang->milestone->targetRange   = '目標控制範圍';
$lang->milestone->ge            = '大於等於';
$lang->milestone->le            = '小於等於';
$lang->milestone->analysis      = '分析結果';
$lang->milestone->PV            = '計劃完成的工作(PV)';
$lang->milestone->EV            = '實際完成的工作(EV)';
$lang->milestone->AC            = '實際花費的成本(AC)';
$lang->milestone->SPI           = '項目進度績效(SPI)';
$lang->milestone->CPI           = '項目成本績效(CPI)';
$lang->milestone->SV            = '進度偏差率(SV%)';
$lang->milestone->CV            = '成本偏差率(CV%)';

$lang->milestone->workHours   = '工作量（人時）';
$lang->milestone->allStage    = '工程階段';
$lang->milestone->devHours    = '研發工作量';
$lang->milestone->toHours     = '返工工作量';
$lang->milestone->reviewHours = '評審工作量';
$lang->milestone->qaHours     = '測試工作量';
$lang->milestone->rowSummary  = '工作量小計';
$lang->milestone->rowPercent  = '分佈百分比(%)';
$lang->milestone->colPercent  = '占工作量百分比(%)';
$lang->milestone->colSummary  = '總和';
$lang->milestone->qatoDev     = '測試研發比';

$lang->milestone->executionRisk     = '5.項目風險(優先最高的前五項風險)';
$lang->milestone->riskCountermove = '風險對策';
$lang->milestone->riskDescriptio  = '風險描述';
$lang->milestone->riskPossibility = '可能性';
$lang->milestone->riskSeriousness = '嚴重性';
$lang->milestone->riskFactor      = '風險係數';
$lang->milestone->riskMeasures    = '風險對策';
$lang->milestone->riskAccumulate  = '累積的高風險';

$lang->milestone->otherIssue       = '其它問題';
$lang->milestone->issueSolutions   = '問題及解決建議';
$lang->milestone->issueDescription = '問題描述';
$lang->milestone->needHelp         = '是否需要高層支持';
$lang->milestone->issuePropose     = '解決建議';

$lang->milestone->demandStatus     = '4.用戶需求狀況分析';
$lang->milestone->storyUnit        = '單位:Item';
$lang->milestone->engineeringStage = '工程階段';
$lang->milestone->rateChange       = '需求變化率';
$lang->milestone->originalStory    = '原始需求數量';
$lang->milestone->modifyNumber     = '變更後需求總數';
$lang->milestone->changeStory      = '變更的需求數';

$lang->milestone->paogressForecast   = '項目進展預測';
$lang->milestone->duration           = '工期(天)';
$lang->milestone->cost               = '成本(人時)';
$lang->milestone->forecastResults    = '預測結果分析';
$lang->milestone->plannedValue       = '計劃值';
$lang->milestone->predictedValue     = '預測值';
$lang->milestone->predictedValueDesc = '計算公式：如果項目進度績效(SPI)=0，那麼預測值=0，否則，預測值=計劃值 除以 項目進度績效(SPI)';
$lang->milestone->periodDeviation    = '工期偏差';
$lang->milestone->costDeviation      = '成本偏差';
$lang->milestone->nextStage          = '下一里程碑階段';
$lang->milestone->overallProject     = '項目總體';
$lang->milestone->corrective         = '糾偏措施';
$lang->milestone->timeOverrun        = '總工期將超出:%s天。';
$lang->milestone->costOverrun        = '總成本將超出:%s個單位。';
$lang->milestone->saveOtherProblem   = '保存其他問題';

$lang->milestone->chart = new stdclass();
$lang->milestone->chart->title    = '到目前為止項目進展趨勢圖';
$lang->milestone->chart->time     = '第';
$lang->milestone->chart->week     = '周';
$lang->milestone->chart->month    = '月';
$lang->milestone->chart->workhour = '研發工作量分析圖';

$lang->milestone->otherproblem      = '6.其它問題';
$lang->milestone->problemandsuggest = '問題及解決建議';
$lang->milestone->suggest           = '解決建議';
$lang->milestone->needhelp          = '是否需要高層支持？';
$lang->milestone->prodescr          = '問題描述';

$lang->milestone->quality = new stdclass();
$lang->milestone->quality->total         = '合計';
$lang->milestone->quality->identify      = '缺陷識別階段';
$lang->milestone->quality->injection     = '缺陷注入階段';
$lang->milestone->quality->scale         = '規模';
$lang->milestone->quality->identifyRate       = '缺陷識別率';
$lang->milestone->quality->injectionRate      = '缺陷注入率';

$lang->milestone->options  = '操作';

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/milestone/lang/zh-tw.php <==
<?php
$lang->milestone->common      = '項目里程碑報告';
$lang->milestone->index       = '報告首頁';
$lang->milestone->title       = '里程碑報告';
$lang->milestone->name        = '里程碑名稱';
$lang->milestone->stage       = '里程碑階段';
$lang->milestone->save        = '保存';

$lang->milestone->indexAction = '里程碑報告';

$lang->milestone->startedWeeks  = '開始周數';
$lang->milestone->finishedWeeks = '結束周數';
$lang->milestone->offset        = '里程碑工期偏差';

$lang->milestone->processCommon = '項目當前進展狀況';
$lang->milestone->process       = '項目進度';
$lang->milestone->executionCost   = '項目成本';
$lang->milestone->toNow         = '到目前為止';
$lang->milestone->targetRange   = '目標控制範圍';
$lang->milestone->ge            = '大於等於';
$lang->milestone->le            = '小於等於';
$lang->milestone->analysis      = '分析結果';
$lang->milestone->PV            = '計劃完成的工作(PV)';
$lang->milestone->EV            = '實際完成的工作(EV)';
$lang->milestone->AC            = '實際花費的成本(AC)';
$lang->milestone->SPI           = '項目進度績效(SPI)';
$lang->milestone->CPI           = '項目成本績效(CPI)';
$lang->milestone->SV            = '進度偏差率(SV%)';
$lang->milestone->CV            = '成本偏差率(CV%)';

$lang->milestone->workHours   = '工作量（人時）';
$lang->milestone->allStage    = '工程階段';
$lang->milestone->devHours    = '研發工作量';
$lang->milestone->toHours     = '返工工作量';
$lang->milestone->reviewHours = '評審工作量';
$lang->milestone->qaHours     = '測試工作量';
$lang->milestone->rowSummary  = '工作量小計';
$lang->milestone->rowPercent  = '分佈百分比(%)';
$lang->milestone->colPercent  = '占工作量百分比(%)';
$lang->milestone->colSummary  = '總和';
$lang->milestone->qatoDev     = '測試研發比';

$lang->milestone->executionRisk     = '5.項目風險(優先最高的前五項風險)';
$lang->milestone->riskCountermove = '風險對策';
$lang->milestone->riskDescriptio  = '風險描述';
$lang->milestone->riskPossibility = '可能性';
$lang->milestone->riskSeriousness = '嚴重性';
$lang->milestone->riskFactor      = '風險係數';
$lang->milestone->riskMeasures    = '風險對策';
$lang->milestone->riskAccumulate  = '累積的高風險';

$lang->milestone->otherIssue       = '其它問題';
$lang->milestone->issueSolutions   = '問題及解決建議';
$lang->milestone->issueDescription = '問題描述';
$lang->milestone->needHelp         = '是否需要高層支持';
$lang->milestone->issuePropose     = '解決建議';

$lang->milestone->demandStatus     = '4.用戶需求狀況分析';
$lang->milestone->storyUnit        = '單位:Item';
$lang->milestone->engineeringStage = '工程階段';
$lang->milestone->rateChange       = '需求變化率';
$lang->milestone->originalStory    = '原始需求數量';
$lang->milestone->modifyNumber     = '變更後需求總數';
$lang->milestone->changeStory      = '變更的需求數';

$lang->milestone->paogressForecast   = '項目進展預測';
$lang->milestone->duration           = '工期(天)';
$lang->milestone->cost               = '成本(人時)';
$lang->milestone->forecastResults    = '預測結果分析';
$lang->milestone->plannedValue       = '計劃值';
$lang->milestone->predictedValue     = '預測值';
$lang->milestone->predictedValueDesc = '計算公式：如果項目進度績效(SPI)=0，那麼預測值=0，否則，預測值=計劃值 除以 項目進度績效(SPI)';
$lang->milestone->periodDeviation    = '工期偏差';
$lang->milestone->costDeviation      = '成本偏差';
$lang->milestone->nextStage          = '下一里程碑階段';
$lang->milestone->overallProject     = '項目總體';
$lang->milestone->corrective         = '糾偏措施';
$lang->milestone->timeOverrun        = '總工期將超出:%s天。';
$lang->milestone->costOverrun        = '總成本將超出:%s個單位。';
$lang->milestone->saveOtherProblem   = '保存其他問題';

$lang->milestone->chart = new stdclass();
$lang->milestone->chart->title    = '到目前為止項目進展趨勢圖';
$lang->milestone->chart->time     = '第';
$lang->milestone->chart->week     = '周';
$lang->milestone->chart->month    = '月';
$lang->milestone->chart->workhour = '研發工作量分析圖';

$lang->milestone->otherproblem      = '6.其它問題';
$lang->milestone->problemandsuggest = '問題及解決建議';
$lang->milestone->suggest           = '解決建議';
$lang->milestone->needhelp          = '是否需要高層支持？';
$lang->milestone->prodescr          = '問題描述';

$lang->milestone->reviewHoursTip = '評審工作量 = 評審時長 * 評審人數';
$lang->milestone->toHoursTip     = '返工工作量統計的是研發任務被激活之後，重新消耗的工時';

$lang->milestone->quality = new stdclass();
$lang->milestone->quality->total         = '合計';
$lang->milestone->quality->identify      = '缺陷識別階段';
$lang->milestone->quality->injection     = '缺陷注入階段';
$lang->milestone->quality->scale         = '規模';
$lang->milestone->quality->identifyRate  = '缺陷識別率';
$lang->milestone->quality->injectionRate = '缺陷注入率';

$lang->milestone->options  = '操作';
